@@ -11,7 +11,7 @@
 // test object
 #include <coordrange.hpp>
 // Qt
-#include <QtTest>
+#include <QTest>
 
 namespace Okteta {
 
@@ -442,3 +442,5 @@ void CoordRangeTest::testIsJoinable()
 }
 
 QTEST_MAIN(Okteta::CoordRangeTest)
+
+#include "moc_coordrangetest.cpp"
