@@ -17,8 +17,13 @@ struct SInt16
 {
 public:
     SInt16(qint16 v);
+    SInt16(const SInt16&) = default;
     SInt16();
 
+    ~SInt16() = default;
+
+    SInt16& operator=(const SInt16&) = default;
+
 public:
     QString toString() const;
 
