@@ -21,8 +21,12 @@ class AbstractFrameRenderer
 {
 public:
     AbstractFrameRenderer();
+    AbstractFrameRenderer(const AbstractFrameRenderer&) = delete;
+
     virtual ~AbstractFrameRenderer();
 
+    AbstractFrameRenderer& operator=(const AbstractFrameRenderer&) = delete;
+
 public: // API to be implemented
     // make this flags?
 //     virtual bool hasFixedWidth() const = 0;
