@@ -10,7 +10,7 @@
 #define KASTEN_ABSTRACTMODELFILESYSTEMSYNCHRONIZER_HPP
 
 // lib
-#include <kasten/abstractmodelsynchronizer.hpp>
+#include "abstractmodelsynchronizer.hpp"
 
 class KDirWatch;
 class QDateTime;
@@ -29,7 +29,7 @@ class KASTENCORE_EXPORT AbstractModelFileSystemSynchronizer : public AbstractMod
     friend class AbstractFileSystemSyncToRemoteJobPrivate;
 
 protected:
-    explicit AbstractModelFileSystemSynchronizer(AbstractModelFileSystemSynchronizerPrivate* d);
+    KASTENCORE_NO_EXPORT explicit AbstractModelFileSystemSynchronizer(AbstractModelFileSystemSynchronizerPrivate* d);
 
 public:
     AbstractModelFileSystemSynchronizer();
