@@ -22,6 +22,11 @@ class AbstractToolWidgetPrivate
 {
 public:
     explicit AbstractToolWidgetPrivate(AbstractToolWidget* parent);
+    AbstractToolWidgetPrivate(const AbstractToolWidgetPrivate&) = delete;
+
+    ~AbstractToolWidgetPrivate() = default;
+
+    AbstractToolWidgetPrivate& operator=(const AbstractToolWidgetPrivate&) = delete;
 
 public:
     void addButton(QPushButton* button, AbstractToolWidget::DefaultType defaultType);
